import React, { useState } from 'react';
import {
  ModalForm,
  ProFormText,
} from '@ant-design/pro-form';
import md5 from 'md5';
import { notification } from 'antd';
import request from '@/utils/request';

export default (props) => {
  const checkSame = ({ getFieldValue }) => ({
    validator(_, value) {
      if (!value || getFieldValue('nw1') === value) {
        return Promise.resolve();
      }

      return Promise.reject(new Error('两次密码输入不一致!'));
    }
  })

  const handleSubmit = (values) => {
    const data = {
      originPassword: md5(values.originPassword),
      newPassword: md5(values.nw1),
    }

    return request('/change-password', { data, method: 'put' }).then(() => {
      props.onFinish()
      return true
    }).catch((e) => {
      notification.error({ message: e.message })
    })
  }

  return (
    <ModalForm width={480} visible={props.visible} onFinish={handleSubmit} onVisibleChange={props.onVisibleChange}>
      <ProFormText.Password
        label="原始密码"
        name="originPassword"
        rules={[{ required: true, message: '原始密码不能为空' }]}
      />
      <ProFormText.Password
        label="新密码"
        name="nw1"
        rules={[{ required: true, message: '新密码不能为空' }]}
      />
      <ProFormText.Password
        label="新密码"
        name="nw2"
        rules={[{ required: true, message: '新密码不能为空' }, checkSame ]}
      />
    </ModalForm>
  )
}
