import React, { useEffect, useState } from 'react';
import { Select, Spin } from 'antd';
import request from '@/utils/request';

export default (props) => {
  const [loading, setLoading] = useState(false);
  const [list, setList] = useState([]);
  const [value, setValue] = useState();

  const filterFunc = (input, option) => {
    return option.children.toLowerCase().indexOf(input.toLowerCase()) >= 0;
  };

  const handleChange = (val) => {
    setValue(val);
    const specialty = list.filter((s) => s.schoolId === val)[0];

    props.onChange(val, specialty);
  };

  useEffect(() => {
    if (props.value !== value) {
      console.log('---------');
      if (!value) {
        setValue();
      } else {
        setValue(props.value);
      }
    }
  }, [props.value, value]);

  useEffect(() => {
    if (props.schoolid) {
      setLoading(true);

      request('/specialty', { params: { schoolId: props.schoolid, pageSize: 100 } })
        .then((res) => {
          const records = res.records || [];
          setList(records);
          setLoading(false);
          setValue();
          // if (props.autoDefault !== false && records.length > 0) {
          //   setValue(records[0].specialty);
          //   props.onChange(records[0].specialtyId, records[0]);
          // }
        })
        .catch((e) => {
          // eslint-disable-next-line
          console.error(e.message);
          setLoading(false);
        });
    }

    // eslint-disable-next-line
  }, [props.schoolid]);

  return (
    <Spin spinning={loading}>
      <Select
        showSearch
        optionFilterProp="children"
        filterOption={filterFunc}
        {...props}
        value={value}
        onChange={handleChange}
        allowClear
      >
        {list.map((s) => (
          <Select.Option key={s.specialtyId} value={s.specialtyId}>
            {s.name}
          </Select.Option>
        ))}
      </Select>
    </Spin>
  );
};
