/**
 * Ant Design Pro v4 use `@ant-design/pro-layout` to handle Layout.
 *
 * @see You can view component api by: https://github.com/ant-design/ant-design-pro-layout
 */
import ProLayout, { DefaultFooter } from '@ant-design/pro-layout';
import React, { useMemo } from 'react';
// import { Link, useIntl, connect, history } from 'umi';
import { Link, connect, history } from 'umi';
// import { GithubOutlined } from '@ant-design/icons';
import { Result, Button } from 'antd';
import Authorized from '@/utils/Authorized';
import { getCurrentRoute } from '@/utils/utils';
import RightContent from '@/components/GlobalHeader/RightContent';
// import { getMatchMenu } from '@umijs/route-utils';
import logo from '../assets/logo.svg';

const noMatch = (
  <Result
    status={403}
    title="403"
    subTitle="Sorry, you are not authorized to access this page."
    extra={
      <Button type="primary">
        <Link to="/user/login">Go Login</Link>
      </Button>
    }
  />
);

/** Use Authorized check all menu item */
const menuDataRender = (menuRoles) => (menuList) =>
  menuList.map((item) => {
    const needAuth = !!item.menuCode;

    const authority =
      (menuRoles.filter((x) => x.menuCode === item.menuCode)[0] || {}).roleString || '';

    const localItem = {
      ...item,
      children: item.children ? menuDataRender(menuRoles)(item.children) : undefined,
    };

    return Authorized.check(needAuth ? authority.split(',') : undefined, localItem, null);
  });

const defaultFooterDom = (
  <DefaultFooter
    copyright={`${new Date().getFullYear()} 云致科技`}
    links={
      [
        // {
        //   key: 'Ant Design Pro',
        //   title: 'Ant Design Pro',
        //   href: 'https://pro.ant.design',
        //   blankTarget: true,
        // },
        // {
        //   key: 'github',
        //   title: <GithubOutlined />,
        //   href: 'https://github.com/ant-design/ant-design-pro',
        //   blankTarget: true,
        // },
        // {
        //   key: 'Ant Design',
        //   title: 'Ant Design',
        //   href: 'https://ant.design',
        //   blankTarget: true,
        // },
      ]
    }
  />
);

const BasicLayout = (props) => {
  const {
    // user,
    menus,
    dispatch,
    children,
    settings,
    location = {
      pathname: '/',
    },
  } = props;

  const handleMenuCollapse = (payload) => {
    if (dispatch) {
      dispatch({
        type: 'global/changeLayoutCollapsed',
        payload,
      });
    }
  }; // get children authority

  const authorized = useMemo(() => {
    const routeItem = getCurrentRoute(location.pathname || '/');
    if (!routeItem || !routeItem.menuCode) {
      return { authority: undefined };
    }

    const authority = (menus.filter((x) => x.menuCode === routeItem.menuCode)[0] || {}).roleString;
    return {
      authority: authority ? authority.split(',') : ['any-string-for-no-right'],
    };
  }, [location.pathname, menus]);

  // const { formatMessage } = useIntl();

  return (
    <ProLayout
      logo={logo}
      // formatMessage={formatMessage}
      {...props}
      {...settings}
      onCollapse={handleMenuCollapse}
      onMenuHeaderClick={() => history.push('/')}
      menuItemRender={(menuItemProps, defaultDom) => {
        if (
          menuItemProps.isUrl ||
          !menuItemProps.path ||
          location.pathname === menuItemProps.path
        ) {
          return defaultDom;
        }

        return <Link to={menuItemProps.path}>{defaultDom}</Link>;
      }}
      breadcrumbRender={(routers = []) => [
        {
          path: '/',
          breadcrumbName: '首页',
          // breadcrumbName: formatMessage({
          //   id: 'menu.home',
          // }),
        },
        ...routers,
      ]}
      itemRender={(route, params, routes, paths) => {
        const first = routes.indexOf(route) === 0;
        return first ? (
          <Link to={paths.join('/')}>{route.breadcrumbName}</Link>
        ) : (
          <span>{route.breadcrumbName}</span>
        );
      }}
      footerRender={() => {
        if (settings.footerRender || settings.footerRender === undefined) {
          return defaultFooterDom;
        }

        return null;
      }}
      menuDataRender={menuDataRender(menus)}
      rightContentRender={() => <RightContent />}
      // waterMarkProps={{
      //   content: '云致科技',
      //   fontColor: 'rgba(24,144,255,0.15)',
      // }}
    >
      <Authorized authority={authorized.authority} noMatch={noMatch}>
        {children}
      </Authorized>
    </ProLayout>
  );
};

export default connect(({ global, settings, user }) => ({
  collapsed: global.collapsed,
  settings,
  user: user.currentUser,
  menus: user.menus,
}))(BasicLayout);
