import React, { useRef, useCallback, useState, useMemo } from 'react';
import { connect, history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import { PlusOutlined, MenuOutlined } from '@ant-design/icons';
import { Button, Popconfirm, Image, Space, notification } from 'antd';
import request, { queryTable } from '@/utils/request';
import DnDProvider from '@/components/DndTr/Provider';
import DndTr from '@/components/DndTr';

const typeList = { post: '科普' };

const HotList = () => {
  const [forceUpdate, setForceUpdate] = useState(1)
  const actRef = useRef()

  // eslint-disable-next-line react-hooks/exhaustive-deps
  const RowWrapper = useMemo(() => DndTr, [forceUpdate])

  const tableWrapper = useMemo(() => ({
    body: {
      wrapper: DnDProvider,
      row: RowWrapper,
    },
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }), [forceUpdate])

  const moveRow = ({ source, target }) => {
    console.log('--------->', source.index, target.index)
    if (source.index === target.index) {
      return
    }

    request('/sort/topic', { method: 'PUT', data: { from: source.index, to: target.index, id: source.id } }).then(() => {
      actRef.current.reload()
      setForceUpdate(forceUpdate + 1)
    }).catch((e) => {
      notification.error({ message: e.message })
    })
  }

  const handleHotClick = useCallback((id) => {
    history.push(id ? `/cms/hot/edit?id=${id}` : '/cms/hot/edit');
  }, []);

  const actions = [
    <Button key="button" icon={<PlusOutlined />} type="primary" onClick={() => handleHotClick()}>
      新建
    </Button>,
  ];

  const deleteHotClick = (id) => {
    setLoading(true);

    request(`/topic/${id}`, { method: 'delete' })
      .then(() => {
        notification.success({ message: '删除成功' });
        // ref.current.submit();
      })
      .catch((e) => {
        setLoading(false);
        notification.error({ message: e.message });
      });
  };

  const changeStatus = (row) => {
    setLoading(true);

    request(`/topic/${row.serialNo}`, {
      method: 'put',
      data: { ...row, status: row.status === 1 ? 0 : 1 },
    })
      .then(() => {
        notification.info({ message: '修改成功' });
        setLoading(false);
        // ref.current.submit();
      })
      .catch((e) => {
        notification.error({ message: e.message });
        setLoading(false);
        return Promise.reject(e.message);
      });
  };

  const columns = [
    {
      title: '排序',
      dataIndex: 'sort',
      width: 60,
      hideInSearch: true,
      align: 'center',
      render: () => (<MenuOutlined style={{ cursor: 'grab', color: '#999' }} />),
    },
    {
      title: '主图',
      dataIndex: 'poster',
      hideInSearch: true,

      align: 'center',
      render: (text) => <Image width={64} height={64} src={text} />,
    },
    {
      title: '文章标题',
      dataIndex: 'targetTitle',
      align: 'center',
      className: 'drag-visible',
    },
    {
      title: '板块',
      dataIndex: 'targetType',
      hideInSearch: true,
      align: 'center',
      render: (text) => typeList[text] || '',
    },

    {
      title: '状态',
      dataIndex: 'status',
      align: 'center',
      hideInSearch: true,
      valueEnum: {
        0: { text: '未启用', status: 'Default' },
        1: { text: '启用', status: 'Success' },
      },
    },
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      hideInSearch: true,
      render: (text, record) => (
        <Space size="middle">
          <a key="status" onClick={() => changeStatus(record)}>
            {record.status === 1 ? '禁用' : '启用'}
          </a>
          <a onClick={() => handleHotClick(record.serialNo)}>编辑</a>
          <Popconfirm
            key="popconfirm"
            title={`确认删除吗?`}
            onConfirm={() => deleteHotClick(record.serialNo)}
            okText="是"
            cancelText="否"
          >
            <a>删除</a>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  const handleRow = useCallback((record) => ({
    index: record.sortNo,
    bizId: record.serialNo,
    moveRow,

  // eslint-disable-next-line react-hooks/exhaustive-deps
  }), [forceUpdate])

  return (
    <PageContainer>
      <ProTable
        pagination={false}
        columns={columns}
        actionRef={actRef}
        request={queryTable('/topic')}
        rowKey="serialNo"
        headerTitle="科普列表"
        search={{ labelWidth: '4em' }}
        components={tableWrapper}
        onRow={handleRow}
        toolBarRender={() => actions}
      />
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(HotList);
