import React, { useEffect, useState } from 'react';
import { connect,history } from 'umi';
import { notification, Tabs,Button } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import request from '@/utils/request';
import PostForm from './components/Form';
import Answer from './components/Answer';
import Share from './components/Share';

const { TabPane } = Tabs;

const PostEdit = (props) => {
  const { id } = props.location.query;
  const [loading, setLoading] = useState(false);
  const [post, setPost] = useState({});

  const handleFormChange = (newPost) => {
    setPost(newPost);
  };

  const handlePostTestChange = (postTestList) => {
    setPost({
      ...post,
      postTestList,
    })
  }

  const handleShareSettingChange = (shareSetting) => {
    setPost({
      ...post,
      shareSetting,
    })
  }

  useEffect(() => {
    if (id) {
      setLoading(true);
      request(`/post/${id}`)
        .then((res) => {
          setPost(res);
          setLoading(false);
        })
        .catch((e) => {
          setLoading(false);
          notification.error({ message: e.message });
        });
    }
  }, [id]);

  useEffect(() => {
    if (!props.typeList || !props.typeList.length) {
      props.dispatch({
        type: 'post/getTypeList',
        payload: { pageSize: 999 },
      });
    }
  }, [props]);

  return (
    <PageContainer
    header={{
      extra: [
        <Button key="1" onClick={() => history.go('-1')}>
          返回
        </Button>,
      ],
    }}>
      <Container>
        <Tabs>
          <TabPane tab="科普信息" key="1">
            <Container loading={loading}>
              <PostForm post={post} typeList={props.typeList} onChange={handleFormChange} />
            </Container>
          </TabPane>
          <TabPane tab="题库设置" key="2">
            <Answer post={post} onChange={handlePostTestChange} />
          </TabPane>
          <TabPane tab="分享设置" key="3">
            <Share post={post} onChange={handleShareSettingChange} />
          </TabPane>
        </Tabs>
      </Container>
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(PostEdit);
