import React, { useEffect, useState } from 'react'
import { Tree, Spin } from 'antd'
import { connect } from 'umi'

const convert2Tree = (arr) => {
  const rootId = -1
  const tree = []

  arr.forEach((menu) => {
    const node = {
      title: menu.name,
      key: menu.menuId,
      data: menu,
    }

    if (menu.children) {
      node.children = menu.children
    } else {
      node.children = []
      // eslint-disable-next-line
      menu.children = node.children
    }

    // 如果是根节点
    if (menu.menuPId === rootId) {
      tree.push(node)
    } else {
      // 否则查询父节点
      let parent = null
      for(let i = 0; i < arr.length; i += 1) {
        if (arr[i].menuId === menu.menuPId) {
          parent = arr[i]
          break
        }
      }

      // 找到父节点, 则处理
      // 否则直接丢弃
      if (parent) {
        if (parent.children) {
          parent.children.push(node)
        } else {
          parent.children = [node]
        }
      }
    }
  })

  return tree
}

const RoelMenu = (props) => {
  const [treeData, setTreeData] = useState([])
  const [expandedKeys, setExpandedKeys] = useState([])
  const [checkedKeys, setCheckedKeys] = useState({ checked: [], halfChecked: [] })

  const handleChecked = (keys, e) => {
    setCheckedKeys({ checked: keys, halfChecked: e.halfCheckedKeys })

    const allChecked = [...keys, ...e.halfCheckedKeys ]
    const allMenus = props.menuList || []
    const checkedMenus = allChecked.map((x) => allMenus.filter((m) => m.menuId === x)[0])
    props.onChange(checkedMenus)
  }

  useEffect(() => {
    // 因为 convert2Tree 方法有对 Object 的写入操作
    // 此方法会触发 treeData 反复生成异常
    // 所以需要进行一次解构操作
    const list = (props.menuList || []).map((x) => ({ ...x, children: undefined }))
    //
    setTreeData(convert2Tree(list))

    // 默认展开全部
    setExpandedKeys(list.map((x) => x.menuId))
  }, [props.menuList])

  useEffect(() => {
    const checked = []
    const halfChecked = []
    const menus = props.roleMenu || []
    const allMenus = props.menuList || []

    menus.forEach((menu) => {
      // 当前选中的子节点
      const checkedChildren = menus.filter((m) => m.menuPId === menu.menuId)
      // 所有的子节点
      const allChildren = allMenus.filter((m) => m.menuPId === menu.menuId)
      // 如果当前选中的子节点全部都在选择列表中
      if (checkedChildren.length === allChildren.length) {
        checked.push(menu.menuId)
      } else {
        halfChecked.push(menu.menuId)
      }
    })

    setCheckedKeys(checked, halfChecked)
    // setCheckedKeys((props.roleMenu || []).map((x) => x.menuId))
  }, [props.roleMenu, props.menuList])

  return (
    <div>
      {
        treeData.length && (
          <Tree
            checkable
            checkedKeys={checkedKeys}
            treeData={treeData}
            defaultExpandedKeys={expandedKeys}
            onCheck={handleChecked}
          />
        )
      }
      { !treeData.length && <Spin />}
    </div>
  )
}

export default connect((s) => ({ menuList: s.user.menus }))(RoelMenu)
