import { useRef } from "react";
import { useDrag, useDrop } from "react-dnd";

export default function useDnD(options, deps) {
  const dndType = 'dnd_item';
  const handleDrop = useRef(x => x);

  const [{ isDragging }, dragSource, dragPreview ] = useDrag(() => ({
    type: options.type || dndType,
    item: options.item,
    collect: (monitor) => ({
      isDragging: monitor.isDragging(),
    }),
  }), deps)

  const [{ isOver }, dropTarget ]  = useDrop(() => ({
    accept: options.type || dndType,
    collect: (monitor) => ({
      isOver: monitor.isOver(),
    }),
    drop: (item) => {
      handleDrop.current(item)
    }
  }), deps)

  const onDrop = (cb) => {
    handleDrop.current = cb
  }

  return {
    dragSource,
    dragPreview,
    dropTarget,
    isDragging,
    isOver,
    onDrop,
  }
}
